BatchConstraintProof

Struct BatchConstraintProof 

pub struct BatchConstraintProof<SC: StarkProtocolConfig> {
    pub numerator_term_per_air: Vec<SC::EF>,
    pub denominator_term_per_air: Vec<SC::EF>,
    pub univariate_round_coeffs: Vec<SC::EF>,
    pub sumcheck_round_polys: Vec<Vec<SC::EF>>,
    pub column_openings: Vec<Vec<Vec<SC::EF>>>,
}

Fields

numerator_term_per_air: Vec<SC::EF>

The terms \textnormal{sum}_{\hat{p}, T, I} as defined in Protocol 3.4.6, per present AIR in sorted AIR order.

denominator_term_per_air: Vec<SC::EF>

The terms \textnormal{sum}_{\hat{q}, T, I} as defined in Protocol 3.4.6, per present AIR in sorted AIR order.

univariate_round_coeffs: Vec<SC::EF>

Polynomial for initial round, given by (vk.d + 1) * (2^{l_skip} - 1) + 1 coefficients.

sumcheck_round_polys: Vec<Vec<SC::EF>>

For rounds 1, ..., n_max; evaluations on {1, ..., vk.d + 1}.

column_openings: Vec<Vec<Vec<SC::EF>>>

Per AIR in sorted AIR order, per AIR part, per column index in that part, openings for the prismalinear column polynomial and (optionally) its rotational convolution. All column openings are stored in a flat way, so only column openings or them interleaved with rotations. For example, if the rotated claims are included for a trace part, then the corresponding list of openings will look like [col_1, rot_1, col_2, rot_2, …], and should be treated as “the i-th column’s plain and rotated claims are (col_i, rot_i)”. Otherwise, it will look like [col_1, col_2, col_3, …], and should be treated as “the i-th column’s plain and rotated claims are (col_i, 0)”. The trace parts are ordered: [CommonMain (part 0), Preprocessed (if any), Cached(0), Cached(1), …]