GkrProof

Struct GkrProof 

pub struct GkrProof<SC: StarkProtocolConfig> {
    pub logup_pow_witness: SC::F,
    pub q0_claim: SC::EF,
    pub claims_per_layer: Vec<GkrLayerClaims<SC>>,
    pub sumcheck_polys: Vec<Vec<[SC::EF; 3]>>,
}

Fields

logup_pow_witness: SC::F

The grinding proof-of-work witness before sampling LogUp alpha,beta

q0_claim: SC::EF

The denominator of the root layer.

Note that the numerator claim is always zero, so we don’t include it in the proof. Despite that the numerator is zero, the representation of the denominator is important for the verification procedure and thus must be provided.

claims_per_layer: Vec<GkrLayerClaims<SC>>

The claims for p_j(xi, 0), p_j(xi, 1), q_j(xi, 0), and q_j(xi, 0) for each layer j > 0.

sumcheck_polys: Vec<Vec<[SC::EF; 3]>>

The sumcheck polynomials for each layer, for each sumcheck round, given by their evaluations on {1, 2, 3}.