pub struct TraceVData<SC: StarkProtocolConfig> {
pub log_height: usize,
pub cached_commitments: Vec<SC::Digest>,
}Fields
log_height: usizeThe base 2 logarithm of the trace height. This should be a nonnegative integer and is
allowed to be < l_skip.
If the corresponding AIR has a preprocessed trace, this must match the value in the vkey.
cached_commitments: Vec<SC::Digest>The cached commitments used.
The length must match the value in the vkey.