pub struct WhirProof<SC: StarkProtocolConfig> {
pub mu_pow_witness: SC::F,
pub whir_sumcheck_polys: Vec<[SC::EF; 2]>,
pub codeword_commits: Vec<SC::Digest>,
pub ood_values: Vec<SC::EF>,
pub folding_pow_witnesses: Vec<SC::F>,
pub query_phase_pow_witnesses: Vec<SC::F>,
pub initial_round_opened_rows: Vec<Vec<Vec<Vec<SC::F>>>>,
pub initial_round_merkle_proofs: Vec<Vec<MerkleProof<SC::Digest>>>,
pub codeword_opened_values: Vec<Vec<Vec<SC::EF>>>,
pub codeword_merkle_proofs: Vec<Vec<MerkleProof<SC::Digest>>>,
pub final_poly: Vec<SC::EF>,
}Expand description
WHIR polynomial opening proof for multiple polynomials of the same height, committed to in multiple commitments.
Fields
mu_pow_witness: SC::FProof-of-work witness for μ batching challenge.
whir_sumcheck_polys: Vec<[SC::EF; 2]>Per sumcheck round; evaluations on {1, 2}. This list is “flattened” with respect to the WHIR rounds.
codeword_commits: Vec<SC::Digest>The codeword commits after each fold, except the final round.
ood_values: Vec<SC::EF>The out-of-domain values “y0” per round, except the final round.
folding_pow_witnesses: Vec<SC::F>For each sumcheck round, the folding PoW witness. Length is num_whir_sumcheck_rounds = num_whir_rounds * k_whir.
query_phase_pow_witnesses: Vec<SC::F>For each WHIR round, the query phase PoW witness. Length is num_whir_rounds.
initial_round_opened_rows: Vec<Vec<Vec<Vec<SC::F>>>>For the initial round: per committed matrix, per in-domain query.
initial_round_merkle_proofs: Vec<Vec<MerkleProof<SC::Digest>>>codeword_opened_values: Vec<Vec<Vec<SC::EF>>>Per non-initial round, per in-domain-query.
codeword_merkle_proofs: Vec<Vec<MerkleProof<SC::Digest>>>final_poly: Vec<SC::EF>Coefficients of the polynomial after the final round.